//  Copyright (C) 2007 Ole Laursen
//  Copyright (C) 2009 Ben Asselstine
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Library General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
//  02110-1301, USA.

#include <config.h>

#include <gtkmm.h>

#include "defs.h"


void show_error(const Glib::ustring &msg)
{
    Gtk::MessageDialog d(msg, Gtk::MESSAGE_ERROR);

    d.set_modal();
    d.set_title(_("Fatal error"));

    d.run();
}

void show_fatal_error(const Glib::ustring &msg)
{
    show_error(msg);
    
    exit(1);
}

